@@ -6,6 +6,8 @@ from numba.experimental import jitclass
 from scipy import ndimage
 import abc
 
+import warnings
+
 from . import shared_tools
 
 # tools for sediment routing algorithms and deposition/erosion
@@ -13,17 +15,23 @@ from . import shared_tools
 
 class sed_tools(abc.ABC):
 
-    def sed_route(self):
+    def route_sediment(self):
         """Sediment routing main method.
 
         This is the main method for sediment routing in the model. It is
         called once per `update()` call.
-        """
-        self.pad_depth = np.pad(self.depth, 1, 'edge')
 
-        self.qs[:] = 0
-        self.Vp_dep_sand[:] = 0
-        self.Vp_dep_mud[:] = 0
+        Internally, this method calls:
+            * :obj:`route_all_sand_parcels`
+            * :obj:`topo_diffusion`
+            * :obj:`route_all_mud_parcels`
+        """
+        _msg = 'Beginning sediment iteration'
+        self.log_info(_msg, verbosity=2)
+
+        # initialize the relevant fields and parcel trackers
+        self.hook_init_sediment_iteration()
+        self.init_sediment_iteration()
 
         _msg = 'Beginning sand parcel routing'
         self.log_info(_msg, verbosity=2)
@@ -40,6 +48,32 @@ class sed_tools(abc.ABC):
         self.hook_route_all_mud_parcels()
         self.route_all_mud_parcels()
 
+    def sed_route(self):
+        """Deprecated, since v1.3.1. Use :obj:`route_sediment`."""
+        _msg = ('`sed_route` and `hook_sed_route` are deprecated and '
+                'have been replaced with `route_sediment`. '
+                'Running `route_sediment` now, but '
+                'this will be removed in future release.')
+        self.logger.warning(_msg)
+        warnings.warn(UserWarning(_msg))
+        self.route_sediment()
+
+    def init_sediment_iteration(self):
+        """Init the water iteration routine.
+
+        Clear and pad fields in preparation for iterating parcels.
+        """
+        _msg = 'Initializing water iteration'
+        self.log_info(_msg, verbosity=2)
+
+        # pad with edge on depth
+        self.pad_depth = np.pad(self.depth, 1, 'edge')
+
+        # clear sediment flux field and deposit volumes
+        self.qs[:] = 0
+        self.Vp_dep_sand[:] = 0
+        self.Vp_dep_mud[:] = 0
+
     def route_all_sand_parcels(self):
         """Route sand parcels; topo diffusion.
 
