@@ -17,15 +17,15 @@ from .. import utilities
 
 
 @mock.patch(
-    'pyDeltaRCM.iteration_tools.iteration_tools.run_one_timestep',
-    new=utilities.FastIteratingDeltaModel.run_one_timestep)
+    'pyDeltaRCM.iteration_tools.iteration_tools.solve_water_and_sediment_timestep',
+    new=utilities.FastIteratingDeltaModel.solve_water_and_sediment_timestep)
 class TestCheckpointingIntegrations:
     """
     The above patch implements an augmented DeltaModel from `utilities`. In
-    this modified DeltaModel, the `run_one_timestep` operations (i.e., the
-    time consuming part of the model) is replaced with an updating random
-    field. This guarantees that the random-repeatedness of checkpointing is
-    validated, but it is much faster and easier to isolate
+    this modified DeltaModel, the `solve_water_and_sediment_timestep`
+    operations (i.e., the time consuming part of the model) is replaced with
+    an updating random field. This guarantees that the random-repeatedness of
+    checkpointing is validated, but it is much faster and easier to isolate
     checkpointing-related issues from model issues.
     """
 
@@ -69,10 +69,8 @@ class TestCheckpointingIntegrations:
         assert np.all(longModel.uy == resumeModel.uy)
         assert np.all(longModel.depth == resumeModel.depth)
         assert np.all(longModel.stage == resumeModel.stage)
-        assert np.all(np.array(longModel.strata_eta.todense()) ==
-                      np.array(resumeModel.strata_eta.todense()))
-        assert np.all(np.array(longModel.strata_sand_frac.todense()) ==
-                      np.array(resumeModel.strata_sand_frac.todense()))
+        assert np.all(longModel.sand_frac == resumeModel.sand_frac)
+        assert np.all(longModel.active_layer == resumeModel.active_layer)
 
         # define another model that loads the checkpoint
         file_name = 'base_run.yaml'
@@ -94,10 +92,8 @@ class TestCheckpointingIntegrations:
         assert np.all(resumeModel2.uy == resumeModel.uy)
         assert np.all(resumeModel2.depth == resumeModel.depth)
         assert np.all(resumeModel2.stage == resumeModel.stage)
-        assert np.all(resumeModel2.strata_eta.todense() ==
-                      resumeModel.strata_eta.todense())
-        assert np.all(resumeModel2.strata_sand_frac.todense() ==
-                      resumeModel.strata_sand_frac.todense())
+        assert np.all(resumeModel2.sand_frac == resumeModel.sand_frac)
+        assert np.all(resumeModel2.active_layer == resumeModel.active_layer)
 
     def test_checkpoint_nc(self, tmp_path):
         """Test the netCDF that is written to by the checkpointing."""
@@ -105,10 +101,10 @@ class TestCheckpointingIntegrations:
         file_name = 'base_run.yaml'
         base_p, base_f = utilities.create_temporary_file(tmp_path, file_name)
         utilities.write_parameter_to_file(base_f, 'out_dir', tmp_path / 'test')
-        utilities.write_parameter_to_file(base_f, 'save_strata', True)
         utilities.write_parameter_to_file(base_f, 'save_eta_grids', True)
         utilities.write_parameter_to_file(base_f, 'save_depth_grids', True)
         utilities.write_parameter_to_file(base_f, 'save_discharge_grids', True)
+        utilities.write_parameter_to_file(base_f, 'save_sandfrac_grids', True)
         utilities.write_parameter_to_file(base_f, 'save_checkpoint', True)
         base_f.close()
         baseModel = DeltaModel(input_file=base_p)
@@ -130,17 +126,14 @@ class TestCheckpointingIntegrations:
         # check that the time makes sense
         assert baseModel.time == baseModel._dt * (nt_base + nt_var)
 
-        # extract the number of times the model has exported data
-        base_n_export = baseModel.strata_counter
-
         # try defining a new model but plan to load checkpoint from baseModel
         file_name = 'base_run.yaml'
         base_p, base_f = utilities.create_temporary_file(tmp_path, file_name)
         utilities.write_parameter_to_file(base_f, 'out_dir', tmp_path / 'test')
-        utilities.write_parameter_to_file(base_f, 'save_strata', True)
         utilities.write_parameter_to_file(base_f, 'save_eta_grids', True)
         utilities.write_parameter_to_file(base_f, 'save_depth_grids', True)
         utilities.write_parameter_to_file(base_f, 'save_discharge_grids', True)
+        utilities.write_parameter_to_file(base_f, 'save_sandfrac_grids', True)
         utilities.write_parameter_to_file(base_f, 'save_checkpoint', False)
         utilities.write_parameter_to_file(base_f, 'resume_checkpoint', True)
         base_f.close()
@@ -158,10 +151,6 @@ class TestCheckpointingIntegrations:
         assert nt_resume > 0
         assert resumeModel.time > baseModel.time
 
-        # extract and compare the number of times exported data
-        resume_n_export = resumeModel.strata_counter
-        assert resume_n_export == (base_n_export * 2) - 1
-
         # assert that output netCDF4 exists
         exp_path_nc = os.path.join(tmp_path / 'test', 'pyDeltaRCM_output.nc')
         assert os.path.isfile(exp_path_nc)
@@ -177,6 +166,7 @@ class TestCheckpointingIntegrations:
         assert 'eta' in out_vars
         assert 'depth' in out_vars
         assert 'discharge' in out_vars
+        assert 'sandfrac' in out_vars
 
         # check attributes of variables
         assert output['time'][0].tolist() == 0.0
@@ -187,6 +177,19 @@ class TestCheckpointingIntegrations:
         assert output['eta'][-1].shape == resumeModel.eta.shape
         assert output['depth'][-1].shape == resumeModel.eta.shape
         assert output['discharge'][-1].shape == resumeModel.eta.shape
+        assert output['sandfrac'][-1].shape == resumeModel.eta.shape
+        # check the metadata
+        assert output['meta']['L0'][:] == resumeModel.L0
+        assert output['meta']['N0'][:] == resumeModel.N0
+        assert output['meta']['CTR'][:] == resumeModel.CTR
+        assert output['meta']['dx'][:] == resumeModel.dx
+        assert output['meta']['h0'][:] == resumeModel.h0
+        assert np.all(output['meta']['cell_type'][:] == resumeModel.cell_type)
+        assert output['meta']['H_SL'][-1].data == resumeModel.H_SL
+        assert output['meta']['f_bedload'][-1].data == resumeModel.f_bedload
+        assert pytest.approx(float(output['meta']['C0_percent'][-1].data) ==
+                             resumeModel.C0_percent)
+        assert output['meta']['u0'][-1].data == resumeModel.u0
 
         # checkpoint interval aligns w/ timestep dt so these should match
         assert output['time'][-1].tolist() == resumeModel.time
@@ -196,7 +199,6 @@ class TestCheckpointingIntegrations:
         # define a yaml for the base model run
         file_name = 'base_run.yaml'
         base_p, base_f = utilities.create_temporary_file(tmp_path, file_name)
-        utilities.write_parameter_to_file(base_f, 'save_strata', True)
         utilities.write_parameter_to_file(base_f, 'save_eta_grids', True)
         utilities.write_parameter_to_file(base_f, 'save_depth_grids', True)
         utilities.write_parameter_to_file(base_f, 'save_discharge_grids', True)
@@ -220,7 +222,6 @@ class TestCheckpointingIntegrations:
         # try defining a new model but plan to load checkpoint from baseModel
         file_name = 'base_run.yaml'
         base_p, base_f = utilities.create_temporary_file(tmp_path, file_name)
-        utilities.write_parameter_to_file(base_f, 'save_strata', True)
         utilities.write_parameter_to_file(base_f, 'save_eta_grids', True)
         utilities.write_parameter_to_file(base_f, 'save_depth_grids', True)
         utilities.write_parameter_to_file(base_f, 'save_discharge_grids', True)
@@ -262,7 +263,6 @@ class TestCheckpointingIntegrations:
         # define a yaml for the base model run
         file_name = 'base_run.yaml'
         base_p, base_f = utilities.create_temporary_file(tmp_path, file_name)
-        utilities.write_parameter_to_file(base_f, 'save_strata', True)
         utilities.write_parameter_to_file(base_f, 'save_eta_grids', True)
         utilities.write_parameter_to_file(base_f, 'save_checkpoint', True)
         utilities.write_parameter_to_file(base_f, 'out_dir', tmp_path / 'test')
@@ -277,7 +277,6 @@ class TestCheckpointingIntegrations:
         # try defining a new model but plan to load checkpoint from baseModel
         file_name = 'base_run.yaml'
         base_p, base_f = utilities.create_temporary_file(tmp_path, file_name)
-        utilities.write_parameter_to_file(base_f, 'save_strata', True)
         utilities.write_parameter_to_file(base_f, 'save_eta_grids', True)
         utilities.write_parameter_to_file(base_f, 'save_checkpoint', True)
         utilities.write_parameter_to_file(base_f, 'resume_checkpoint', True)
@@ -434,7 +433,8 @@ class TestCheckpointingCreatingLoading:
         """
         # define a yaml with outputs (defaults will output strata)
         p = utilities.yaml_from_dict(tmp_path, 'input.yaml',
-                                     {'save_checkpoint': True})
+                                     {'save_checkpoint': True,
+                                      'save_eta_grids': True})
         _delta = DeltaModel(input_file=p)
 
         # replace eta with a random field for checkpointing success check
@@ -466,8 +466,7 @@ class TestCheckpointingCreatingLoading:
         """
         # define a yaml with NO outputs, but checkpoint
         p = utilities.yaml_from_dict(tmp_path, 'input.yaml',
-                                     {'save_checkpoint': True,
-                                      'save_strata': False})
+                                     {'save_checkpoint': True})
 
         _delta = DeltaModel(input_file=p)
 
@@ -486,8 +485,7 @@ class TestCheckpointingCreatingLoading:
         # can be resumed
         p = utilities.yaml_from_dict(tmp_path, 'input.yaml',
                                      {'save_checkpoint': True,
-                                      'resume_checkpoint': True,
-                                      'save_strata': False})
+                                      'resume_checkpoint': True})
         _delta = DeltaModel(input_file=p)
 
         # check that fields match
@@ -498,8 +496,7 @@ class TestCheckpointingCreatingLoading:
         """
         # define a yaml with NO outputs, but checkpoint
         p = utilities.yaml_from_dict(tmp_path, 'input.yaml',
-                                     {'save_checkpoint': True,
-                                      'save_strata': True})
+                                     {'save_checkpoint': True})
         _delta = DeltaModel(input_file=p)
 
         # replace eta with a random field for checkpointing success check
@@ -510,17 +507,16 @@ class TestCheckpointingCreatingLoading:
         _delta.output_checkpoint()  # force another checkpoint
         _delta.finalize()
 
-        # check that files exist, and then delete nc
-        assert os.path.isfile(os.path.join(
+        # should be no nc file but should be a checkpoint file
+        assert not os.path.isfile(os.path.join(
             _delta.prefix, 'pyDeltaRCM_output.nc'))
         assert os.path.isfile(os.path.join(
             _delta.prefix, 'checkpoint.npz'))
-        os.remove(os.path.join(
-            _delta.prefix, 'pyDeltaRCM_output.nc'))
 
         # now try to resume, will WARN on not finding netcdf
         p = utilities.yaml_from_dict(tmp_path, 'input.yaml',
                                      {'save_checkpoint': True,
+                                      'save_eta_grids': True,
                                       'resume_checkpoint': True})
         with pytest.warns(UserWarning, match=r'NetCDF4 output *.'):
             _delta = DeltaModel(input_file=p)
@@ -535,8 +531,8 @@ class TestCheckpointingCreatingLoading:
         assert np.all(_delta.eta == _rand_field)
 
     @mock.patch(
-        'pyDeltaRCM.iteration_tools.iteration_tools.run_one_timestep',
-        new=utilities.FastIteratingDeltaModel.run_one_timestep)
+        'pyDeltaRCM.iteration_tools.iteration_tools.solve_water_and_sediment_timestep',
+        new=utilities.FastIteratingDeltaModel.solve_water_and_sediment_timestep)
     @pytest.mark.skipif(
         platform.system() != 'Linux',
         reason='Parallel support only on Linux OS.')
@@ -548,7 +544,6 @@ class TestCheckpointingCreatingLoading:
         # define a yaml with an output and checkpoint
         p = utilities.yaml_from_dict(tmp_path, 'input.yaml',
                                      {'save_checkpoint': True,
-                                      'save_strata': True,
                                       'save_eta_grids': True})
         baseModel = DeltaModel(input_file=p)
 
@@ -584,7 +579,6 @@ class TestCheckpointingCreatingLoading:
         # set up a matrix of runs
         resume_dict = {'save_checkpoint': False,
                        'resume_checkpoint': True,
-                       'save_strata': True,
                        'save_eta_grids': True,
                        'out_dir': os.path.join(tmp_path, 'matrix'),
                        'parallel': 4}
@@ -636,3 +630,118 @@ class TestCheckpointingCreatingLoading:
             # netcdf is not expanded to begin at _save_ter from the initial
             # basemodel
             assert output['time'].shape[0] <= (bmsi // 2)
+
+    @pytest.mark.skipif(
+        platform.system() == 'Windows',
+        reason='OS differences regarding netCDF permissions.')
+    def test_load_checkpoint_with_open_netcdf(self, tmp_path):
+        """Test what happens if output netCDF file is actually open.
+
+        This is not the same as when the netCDF file is open in another
+        process. That situation raises an error for all OS.
+        """
+        # define a yaml with outputs (defaults will output strata)
+        p = utilities.yaml_from_dict(tmp_path, 'input.yaml',
+                                     {'save_checkpoint': True,
+                                      'save_eta_grids': True})
+        _delta = DeltaModel(input_file=p)
+
+        # replace eta with a random field for checkpointing success check
+        _rand_field = np.random.uniform(0, 1, size=_delta.eta.shape)
+        _delta.eta = _rand_field
+
+        _delta._save_time_since_checkpoint = float("inf")
+        _delta.output_checkpoint()  # force another checkpoint
+        _delta.finalize()
+
+        # paths exists
+        assert os.path.isfile(os.path.join(
+            _delta.prefix, 'pyDeltaRCM_output.nc'))
+        assert os.path.isfile(os.path.join(
+            _delta.prefix, 'checkpoint.npz'))
+        _prefix = _delta.prefix
+        _delta = []  # clear
+
+        # open the netCDF file
+        _opened = Dataset(os.path.join(_prefix, 'pyDeltaRCM_output.nc'),
+                          'r+', format='NETCDF4')
+        assert type(_opened) == Dataset
+        assert 'eta' in _opened.variables.keys()
+        # saved grid is the initial one, before random field was assigned
+        assert np.all(_opened.variables['eta'][:].data != _rand_field)
+
+        # can be resumed
+        p = utilities.yaml_from_dict(tmp_path, 'input.yaml',
+                                     {'save_checkpoint': True,
+                                      'resume_checkpoint': True,
+                                      'save_eta_grids': True})
+        _delta = DeltaModel(input_file=p)
+        # force save grids/figs
+        _delta.save_grids_and_figs()
+
+        # check that fields match
+        assert np.all(_delta.eta == _rand_field)
+        # assert that old netCDF object is still around and hasn't changed
+        assert type(_opened) == Dataset
+        assert 'eta' in _opened.variables.keys()
+        # grid from old netCDF is initial one, before random field was assigned
+        assert np.all(_opened.variables['eta'][:].data != _rand_field)
+
+        # clear delta
+        _delta = []
+        # open the new netCDF file
+        _new = Dataset(os.path.join(_prefix, 'pyDeltaRCM_output.nc'),
+                       'r+', format='NETCDF4')
+        # first grid should be the OG one
+        assert np.all(_opened['eta'][:].data == _new['eta'][0, :, :].data)
+        # random field should be saved in the new netCDF file
+        # some rounding/truncation happens in the netCDF so we use approx
+        assert pytest.approx(_rand_field == _new['eta'][1, :, :].data)
+
+    @pytest.mark.skipif(
+        platform.system() != 'Windows',
+        reason='OS differences regarding netCDF permissions.')
+    def test_load_checkpoint_with_open_netcdf_win(self, tmp_path):
+        """Test what happens if output netCDF file is actually open.
+
+        This is not the same as when the netCDF file is open in another
+        process. That situation raises an error for all OS.
+        """
+        # define a yaml with outputs (defaults will output strata)
+        p = utilities.yaml_from_dict(tmp_path, 'input.yaml',
+                                     {'save_checkpoint': True,
+                                      'save_eta_grids': True})
+        _delta = DeltaModel(input_file=p)
+
+        # replace eta with a random field for checkpointing success check
+        _rand_field = np.random.uniform(0, 1, size=_delta.eta.shape)
+        _delta.eta = _rand_field
+
+        _delta._save_time_since_checkpoint = float("inf")
+        _delta.output_checkpoint()  # force another checkpoint
+        _delta.finalize()
+
+        # paths exists
+        assert os.path.isfile(os.path.join(
+            _delta.prefix, 'pyDeltaRCM_output.nc'))
+        assert os.path.isfile(os.path.join(
+            _delta.prefix, 'checkpoint.npz'))
+        _prefix = _delta.prefix
+        _delta = []  # clear
+
+        # open the netCDF file
+        _opened = Dataset(os.path.join(_prefix, 'pyDeltaRCM_output.nc'),
+                          'r+', format='NETCDF4')
+        assert type(_opened) == Dataset
+        assert 'eta' in _opened.variables.keys()
+        # saved grid is the initial one, before random field was assigned
+        assert np.all(_opened.variables['eta'][:].data != _rand_field)
+
+        # can be resumed
+        p = utilities.yaml_from_dict(tmp_path, 'input.yaml',
+                                     {'save_checkpoint': True,
+                                      'resume_checkpoint': True,
+                                      'save_eta_grids': True})
+        # raises a permissions error on Windows
+        with pytest.raises(PermissionError):
+            _ = DeltaModel(input_file=p)
